package cz.zcu.kiv.vsp.msloup.patient;

import cz.zcu.fav.kiv.jsim.JSimInvalidParametersException;
import cz.zcu.fav.kiv.jsim.JSimProcess;
import cz.zcu.fav.kiv.jsim.JSimSecurityException;
import cz.zcu.fav.kiv.jsim.JSimSimulation;
import cz.zcu.fav.kiv.jsim.JSimSimulationAlreadyTerminatedException;
import cz.zcu.fav.kiv.jsim.JSimTooManyProcessesException;
import cz.zcu.kiv.vsp.msloup.generator.IGenerator;
import cz.zcu.kiv.vsp.msloup.request.IRequestInput;
import cz.zcu.kiv.vsp.msloup.util.Counter;

/**
 * Generuje pacienty v simulaci
 * @author Martin Sloup
 *
 */
public class PatientGenerator extends JSimProcess {
	private IGenerator generator;
	private IRequestInput output;
	private Counter count;
	private long generatedRequestCount;

	/**
	 * Konstruktor generatoru pacientu v simulaci
	 * @param name			nazev objektu v simulaci
	 * @param simulation	objekt simulatoru
	 * @param generator		objekt generatoru doby cekani mezi generovanim pacientu
	 * @param count			pocet generovanych pacientu
	 * @exception JSimSimulationAlreadyTerminatedException
	 *                Vyjimka je vyhozena, pokud simulace byla jiz ukocena.
	 * @exception JSimInvalidParametersException
	 *                Vyjimka je vyhozena, pokud neni specifikovan objekt simulatoru.
	 * @exception JSimTooManyProcessesException
	 *                Vyjimka je vyhozena, pokud neni mozne jiz do simulatoru pridat dalsi proces.
	 */
	public PatientGenerator(String name, JSimSimulation simulation, IGenerator generator, Counter count)
			throws JSimSimulationAlreadyTerminatedException,
			JSimInvalidParametersException, JSimTooManyProcessesException {
		super(name, simulation);

		this.generator = generator;
		this.count = count;

		generatedRequestCount = 0;
	}

	/**
	 * Zivotni cyklus generatoru pacientu
	 */
	@Override
	protected void life() {
		try {
			while(count == null || count.dec() > 0) {
				hold(Math.abs(generator.nextValue()));

				generatedRequestCount++;

				if (output != null)
					output.receiveRequest(new Patient(myParent.getCurrentTime()));

			}

		} catch (JSimSecurityException e) {
			e.printStackTrace();
		} catch (JSimInvalidParametersException e) {
			e.printStackTrace();
		}
	}

	/**
	 * Nastavuje prijemce vygenerovaneho pacienta
	 * @param output	prijemce pacienta
	 */
	public void setOutput(IRequestInput output) {
		this.output = output;
	}

	/**
	 * Vraci objekt, ktery prijima vygenerovane pacienty
	 * @return	objekt prijemce pacienta
	 */
	public IRequestInput getOutput() {
		return output;
	}

	/**
	 * Vraci generator doby cekani mezi generovanim pacientu
	 * @return	generator cekani
	 */
	public IGenerator getGenerator() {
		return generator;
	}

	/**
	 * Vraci stredni celkovy pocet pacientu
	 * @return	stredni celkovy pocet pacientu
	 */
	public double getLq() {
		return myParent.getCurrentTime() / generatedRequestCount;
	}

	/**
	 * Vraci pocet vytvorenych pacientu
	 * @return	pocet pacientu
	 */
	public long getRequestCount() {
		return generatedRequestCount;
	}

}
