package cz.zcu.kiv.vsp.msloup.generator;


/**
 * Generator normaloveho (Gauss) rozdeleni s parametrem mu a sigma. Vypocet hodnot
 * je proveden pomoci centralni limitni vety.<br>
 * <br>
 * Priklad pouziti:<br>
 * <br>
 * <pre><code> IGenerator gen = new GaussianGenerator(0, 1);
 * System.out.println(gen.nextValue()); // vypise vygenerovanou hodnotu</code></pre>
 *
 * @author Martin Sloup
 */
public class GaussianGenerator implements IGenerator {
	private double mi;
	private double sigma;
	private IGenerator uniformGenerator;

	/**
	 * Konstruktor generatoru normaloveho (Gauss) rozdeleni se stredni hodnotou mu a rozptylem sigma
	 * @param mi	stredni hodnota
	 * @param sigma	rozptyl
	 */
	public GaussianGenerator(double mi, double sigma) {
		this.mi = mi;
		this.sigma = sigma;

		uniformGenerator = new UniformGenerator(0, 1);
	}

	/**
	 * Vygeneruje dalsi hodnotu normaloveho (Gauss) rozdeleni a vrati ji.
	 * @return	vygenerovanou hodnotu
	 */
	@Override
	public double nextValue() {
		// provedeme generovani cisla pomoci centralni limitni vety
		return (sigma * (generateSumOfTwelveUniformNumber() - 6.0) + mi);
	}

	/**
	 * Vraci nahodne rozdeleni, ktere je souctem 12 cisel spojiteho
	 * rovnomereneho rozdeleni. Toto cislo je v rozsahu <0,12).
	 * @return	vygenerovana hodnota
	 */
	private double generateSumOfTwelveUniformNumber() {
		double sum = 0;

		for(int i = 0; i < 12; i++)
			sum+= uniformGenerator.nextValue();

		return sum;
	}

}
