package cz.zcu.kiv.vsp.msloup.object;

import cz.zcu.fav.kiv.jsim.JSimSimulation;
import cz.zcu.kiv.vsp.msloup.request.IRequest;
import cz.zcu.kiv.vsp.msloup.request.IRequestInput;
import cz.zcu.kiv.vsp.msloup.util.Counter;

/**
 * Slouzi k pocitani dokoncenych pozadavku tak, aby se mohla ukoncit simulace
 * @author Martin Sloup
 */
public class Terminator implements IRequestInput {
	private Counter count;
	private long requestCount;
	private double sumOfTq;
	private JSimSimulation simulation;

	/**
	 * Konstruktor tridy s udanim parametru pocitadla, na kterem se bude odecitat.
	 * @param count	objekt pocitadla, u ktereho se po prijeni pozadavku odecita.
	 * @param simulation
	 */
	public Terminator(Counter count, JSimSimulation simulation) {
		this.count = count;
		this.simulation = simulation;
	}

	@Override
	public void receiveRequest(IRequest request) {
		count.dec();
		requestCount++;
		sumOfTq+= simulation.getCurrentTime() - request.getInputTime();
	}

	/**
	 * Vraci soucet strednich dob odezvy simulace
	 * @return	soucet strednich dob odezvy
	 */
	public double getSumOfTq() {
		return sumOfTq;
	}

	/**
	 * Vraci pocet prijatych pozadavku
	 * @return	pocet prijatych pozadavku
	 */
	public long getRequestCount() {
		return requestCount;
	}

}
