package cz.zcu.kiv.vsp.msloup.test;

import java.text.DecimalFormat;
import java.text.NumberFormat;
import cz.zcu.kiv.vsp.msloup.Config;
import cz.zcu.kiv.vsp.msloup.generator.IGenerator;

/**
 * Testovaci trida pro vypis histogramu zadaneho generatoru rozdeleni
 * @author Martin Sloup
 */
public class Histogram {
	private IGenerator generator;
	private int count;
	private final static int HISTOGRAM_LENGTH = 16;

	private double[] values;

	private double Sx = 0;
	private double Sx2 = 0;

	private double min = Double.MAX_VALUE;
	private double max = Double.MIN_VALUE;


	/**
	 * Konstruktor testovaci tridy pro vypis histogramu
	 * @param generator		genarator rozdeleni
	 * @param count			pocet generovanych hodnot
	 */
	public Histogram(IGenerator generator, int count) {
		this.generator = generator;
		this.count = count;

		values = new double[count];
	}

	/**
	 * Spusti generovani hodnot
	 */
	public void start() {
		//vygenerovani hodnot
		for (int i = 0; i < values.length; i++) {
			double value = generator.nextValue();

			//pocitani hodnot pro stredni hodnotu a rozptyl
			Sx+= value;
			Sx2+= value * value;

			//nalezeni minima a maxima
			if (value < min) min = value;
			if (value > max) max = value;

			values[i] = value;
		}
	}

	/**
	 * Vrati histogram o zadanem poctu sloupcu
	 * @param size pocet sloupcu histogramu
	 * @return	histogram
	 */
	public int[] getHistogram(int size) {
		int[] histogram = new int[size + 1];
		double step = getHistogramStep(size);

		for(double value: values) {
			//pridani hodnoty do histogramu
			int index = (int) (((value - min) / step));
			histogram[index]++;
		}

		return histogram;
	}

	/**
	 * Vraci velikost kroku
	 * @param size	velikost histrogramu (pocet sloupcu)
	 * @return	velikost kroku
	 */
	public double getHistogramStep(int size) {
		return Math.abs(max-min) / size;
	}

	/**
	 * Vypise histogram, strednihodotu a rozptyl pro zadany generator
	 */
	public void show() {
		NumberFormat numberFormat = new DecimalFormat("0000");
		NumberFormat doubleFormat = new DecimalFormat("0.0000");


		//zobrazeni vysledku
		System.out.println("Stredni hodnota: " + doubleFormat.format(getComputedE()));
		System.out.println("Rozptyl: " + doubleFormat.format(getComputedD()));
		System.out.println("Minimum: " + doubleFormat.format(min));
		System.out.println("Maximum: " + doubleFormat.format(max));

		int[] histogram = getHistogram(HISTOGRAM_LENGTH);

		//zjistime maximalni hodnotu
		int max_value = 0;
		for(int i = 0; i < histogram.length; i++) {
			if (histogram[i] > max_value) max_value = histogram[i];
		}

		for(int i = 0; i < histogram.length; i++) {
			int value = histogram[i];
			System.out.print(doubleFormat.format(min + i * getHistogramStep(histogram.length)));
			System.out.print(". - ");
			System.out.print(numberFormat.format(value));
			System.out.print(" - ");

			int star_count = (int) (((double)value / max_value) * Config.MAX_STAR_LENGTH);

			for(int y = 0; y < star_count; y++)
				System.out.print(Config.STAR_CHAR);

			System.out.print('\n');
		}
	}

	/**
	 * Vrati vypocitany rozptyl z vygenerovanych cisel
	 * @return	rozptyl
	 */
	public double getComputedD() {
		return (((double)Sx2) / count) - getComputedE() * getComputedE();
	}

	/**
	 * Vrati vypocitanou stredni hodnotu z vygenerovanych cisel
	 * @return	stredni hodnota
	 */
	public double getComputedE() {
		return ((double)Sx) / count;
	}
}
